@@ -22,9 +22,9 @@ from ask_sdk_model.directive import Directive
 
 
 if typing.TYPE_CHECKING:
-    from typing import Dict, List, Optional, Union
+    from typing import Dict, List, Optional, Union, Any
     from datetime import datetime
-    from ask_sdk_model.interfaces.audioplayer.clear_behavior import ClearBehavior
+    from ask_sdk_model.interfaces.audioplayer.clear_behavior import ClearBehavior as ClearBehavior_94e71750
 
 
 class ClearQueueDirective(Directive):
@@ -46,7 +46,7 @@ class ClearQueueDirective(Directive):
     supports_multiple_types = False
 
     def __init__(self, clear_behavior=None):
-        # type: (Optional[ClearBehavior]) -> None
+        # type: (Optional[ClearBehavior_94e71750]) -> None
         """
 
         :param clear_behavior: 
